
*************
Python module
*************

Overview
========

Convenience functions
---------------------

.. autosummary::

  GooseHDF5.dump
  GooseHDF5.copy
  GooseHDF5.copy_dataset
  GooseHDF5.copydatasets
  GooseHDF5.compare
  GooseHDF5.compare_rename

Manipulate path
---------------

.. autosummary::

  GooseHDF5.abspath
  GooseHDF5.join

Iterators
---------

.. autosummary::

  GooseHDF5.getdatapaths
  GooseHDF5.getdatasets
  GooseHDF5.getgroups
  GooseHDF5.filter_datasets
  GooseHDF5.copydatasets

Verify
------

.. autosummary::

  GooseHDF5.verify
  GooseHDF5.exists
  GooseHDF5.exists_any
  GooseHDF5.exists_all
  GooseHDF5.equal
  GooseHDF5.allequal

Documentation
=============

.. automodule:: GooseHDF5
  :members:
